# Copyright(c) 2020-2021 by craftyguy "Clayton Craft" <clayton@craftyguy.net>
# Distributed under GPLv3+ (see COPYING) WITHOUT ANY WARRANTY.
import configparser
import os
from .logger import Logger

APP_NAME = 'caerbannog'
DEFAULT_CLIPBOARD_TIMEOUT_SECS = 45
DEFAULT_PASSWORD_STORE_HOME = '~/.password-store'


class Config():
    def __init__(self):
        super().__init__()
        self._config = configparser.ConfigParser()

        # look for existing config file, create new one if needed
        config_dir_parent = os.environ.get('XDG_CONFIG_HOME')
        if not config_dir_parent:
            config_dir_parent = os.path.expanduser('~/.config')
        config_dir = os.path.join(config_dir_parent, APP_NAME)
        os.makedirs(config_dir, exist_ok=True)
        self._config_file = os.path.join(config_dir, 'config')

        if not os.path.exists(self._config_file):
            Logger.info('config file not found, creating one...')
            self._init_new_config()
        self._config.read(self._config_file)

    def _init_new_config(self):
        # Default options
        self._config['general'] = {}
        self.set('general', 'pass_store_home', DEFAULT_PASSWORD_STORE_HOME)
        self.set('general', 'clipboard_timeout_seconds',
                 DEFAULT_CLIPBOARD_TIMEOUT_SECS)
        self.set('general', 'dark_theme', False)

    def set(self, section, setting, value, save=True):
        if section not in self._config:
            self._config.add_section(section)
        self._config[section][setting] = str(value)
        if save:
            self.save()

    def get(self, section, setting, default=None):
        if section not in self._config:
            return default
        if setting not in self._config[section]:
            return default
        return self._config[section][setting]

    def save(self):
        with open(self._config_file, 'w') as f:
            self._config.write(f)
