# Copyright(c) 2020-2021 by craftyguy "Clayton Craft" <clayton@craftyguy.net>
# Distributed under GPLv3+ (see COPYING) WITHOUT ANY WARRANTY.
import gi
from .logger import Logger
gi.require_version('Gtk', '3.0')
gi.require_version('Handy', '1')
from gi.repository import Gtk
from gi.repository import Handy

APP_NAME = 'caerbannog'
APP_ID = f"net.craftyguy.{APP_NAME}"
UI_PATH = '/net/craftyguy/caerbannog/ui/'


@Gtk.Template(resource_path=UI_PATH+'preferences.ui')
class PrefsWindow(Handy.PreferencesWindow):
    __gtype_name__ = 'PrefsWindow'
    pass_store_path_entry: Gtk.Entry = Gtk.Template.Child()
    clipboard_timeout_entry: Gtk.Entry = Gtk.Template.Child()
    dark_mode_switch: Gtk.Switch = Gtk.Template.Child()

    def __init__(self, config, **kwargs):
        super().__init__(**kwargs)
        self._config = config
        self.pass_store_path_entry.set_text(self._config.get('general',
                                                             'pass_store_home'))
        self.pass_store_path_entry.connect("focus-out-event",
                                           self._on_pass_store_path_entry_focus_out)
        clipboard_timeout_seconds = self._config.get('general',
                                                     'clipboard_timeout_seconds')
        if not clipboard_timeout_seconds:
            clipboard_timeout_seconds = "45"
        self.clipboard_timeout_entry.set_text(clipboard_timeout_seconds)
        self.clipboard_timeout_entry.connect("focus-out-event",
                                             self._on_clipboard_timeout_entry_focus_out)

        self.dark_mode_switch.set_state(self._config.get('general',
                                                         'dark_theme', False))
        self.dark_mode_switch.connect("notify::active",
                                      self._on_dark_mode_switch_flip)

    def _on_dark_mode_switch_flip(self, switch, _):
        use_dark_theme = switch.get_active()
        Logger.info(f"use dark theme: {use_dark_theme}")
        self._config.set('general', 'dark_theme', use_dark_theme)
        # apply selection immediately
        Gtk.Settings.get_default().set_property("gtk-application-prefer-dark-theme",
                                                use_dark_theme)

    def _on_pass_store_path_entry_focus_out(self, entry, userdata):
        new_home = entry.get_text()
        Logger.info(f"setting password-store home: {new_home}")
        self._config.set('general', 'pass_store_home', new_home)

    def _on_clipboard_timeout_entry_focus_out(self, entry, userdata):
        timeout = entry.get_text()
        try:
            timeout = int(timeout)
        except ValueError:
            timeout = 45
            Logger.error("Invalid clipboard timeout entered, using default "
                         f"of {timeout}")
        Logger.info(f"setting clipboard timeout: {timeout}")
        self._config.set('general', 'clipboard_timeout_seconds', timeout)
